@@ -7,8 +7,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/nginxinc/nginx-plus-go-client/v2/client"
-	"github.com/nginxinc/nginx-plus-go-client/v2/tests/helpers"
+	"github.com/nginx/nginx-plus-go-client/v2/client"
+	"github.com/nginx/nginx-plus-go-client/v2/tests/helpers"
 )
 
 const (
